# RCPCHGrowth

[![DOI](https://zenodo.org/badge/361149103.svg)](https://zenodo.org/badge/latestdoi/361149103)

A python package to produce calculations for all growth issues, produced and validated by The Royal College of Paediatrics and Child Health ([RCPCH](https://growth.rcpch.ac.uk/)).

All documentation for implementation can be found [here](https://github.io.)
